@@ -31,7 +31,6 @@ class TextDiscriminator(Discriminator):
 
         logger.info('Overriding class: Discriminator -> TextDiscriminator.')
 
-        # Overrides its parent class with any custom arguments if needed
         super(TextDiscriminator, self).__init__(name='D_text')
 
         # Creates an embedding layer
@@ -51,9 +50,6 @@ class TextDiscriminator(Discriminator):
         # Defining the dropout layer
         self.drop = Dropout(dropout_rate, name='drop')
 
-        # And finally, defining the output layer
-        self.out = Dense(2, name='out')
-
         logger.info('Class overrided.')
 
     def call(self, x, training=True):
@@ -91,6 +87,6 @@ class TextDiscriminator(Discriminator):
         x = tf.math.sigmoid(hw) * tf.nn.relu(hw) + (1 - tf.math.sigmoid(hw)) * x
 
         # Calculating the output with a dropout regularization
-        x = self.out(self.drop(x, training=training))
+        x = self.drop(x, training=training)
 
         return x
